@@ -49,26 +49,27 @@ def _queryAndPrint(q,fields=None,systemFields=True,nullFields=False):
 
     res = query.queryRecords(q)
     if fields != None:
-        res = utils.deleteNulls(res,systemFields==False,nullFields==False)
+        res = utils.deleteNulls(res,systemFields,nullFields)
         if fields=='all':
             utils.printFormated(res)
         else:
             utils.printFormated(res,fields)
     else:
-        res = utils.deleteNulls(res,systemFields==False,nullFields==False)
+        res = utils.deleteNulls(res,systemFields,nullFields)
         print(simplejson.dumps(res, indent=4))
     
     print()
-    print(f"Null values -> {nullFields}  systemFields --> {systemFields}")
+    print(f"Null values printed-> {nullFields}  systemFields printed--> {systemFields}")
 
 def option_q(args):
     if '-h' in args:
-        help = """
-        -q "select..." query to execute. 
-            -null - will print null values as well
-            -system - will print the system fields
-            -fields "a:b:c:..."
-            -fields all"""
+        help = f"""
+        {utils.CGREEN}-q "select..."{utils.CEND} query to execute. System Fields, such as LastModifiedDate, and null fields are not returned. 
+            {utils.CGREEN}-null{utils.CEND} - will print fields with null values
+            {utils.CGREEN}-system{utils.CEND} - will print the system fields
+            {utils.CGREEN}-all{utils.CEND} - will print both nulls and system fields
+            {utils.CGREEN}-fields "a:b:c:..."{utils.CEND} --> print in table format the specified fields.
+            {utils.CGREEN}-fields all{utils.CEND} --> print in table format"""
         return help
 
     #else:
@@ -77,15 +78,19 @@ def option_q(args):
     fields = getParam(args,'-fields') if '-fields' in args else None    
     nullFields = True if '-null' in args else False
     systemFields = True if '-system' in args else False
+    all = True if '-all' in args else False
+    if all == True:
+        nullFields = True
+        systemFields = True
 
     connectionInit(args)
 
-    _queryAndPrint(q,fields=None,systemFields=True,nullFields=False)
+    _queryAndPrint(q,fields=fields,systemFields=systemFields,nullFields=nullFields)
 
 def option_checkCatalogs(args):
     if '-h' in args:
-        help = """
-        -checkCatalogs 
+        help = f"""
+        {utils.CGREEN}-checkCatalogs{utils.CEND} 
             Checks the catalogs. Gets all catalogs, does a getOffers, getOfferDetails, basketwithoutconfig and basket with config
             path: the path to a child product to configure. Path = ... ProductCode ... ProdcutCode
             quantity: the quantity for the object""" 
@@ -101,9 +106,9 @@ def option_checkCatalogs(args):
     print()
 
 def option_d(args):
-    help = """
-        -d objectName --> Describe an object
-            -d objectName:fieldName --> describe a field in the objec"""
+    help = f"""
+        {utils.CGREEN}-d objectName{utils.CEND} --> Describe an object
+            {utils.CGREEN}-d objectName:fieldName{utils.CEND} --> describe a field in the objec"""
     if '-h' in args:
         return help    
 
@@ -129,8 +134,8 @@ def option_d(args):
 
 def option_l(args):
     if '-h' in args:
-        help = """
-        -l --> current org limits consuptions. """
+        help = f"""
+        {utils.CGREEN}-l{utils.CEND} --> current org limits consuptions. """
         return help
     connectionInit(args)
     action = '/services/data/v51.0/limits'
@@ -156,11 +161,12 @@ def option_l(args):
 
 def option_o(args):
     if '-h' in args:
-        help = """
-        -o --> List all Objects
-            -like name
-            objectName  --> get one row from the object
-            objectName:Id --> get the row especified by the Id"""
+        help = f"""
+        {utils.CGREEN}-o{utils.CEND} --> List all Objects
+            {utils.CGREEN}objectName{utils.CEND}  --> get one row from the object
+            {utils.CGREEN}objectName:Id{utils.CEND} --> get the row especified by the Id
+            {utils.CGREEN}-like name{utils.CEND} --> where the Name contains the substring name"""
+
         return help
         
     connectionInit(args)
@@ -213,10 +219,10 @@ def option_o(args):
     utils.printFormated(outs,'name:label:associateParentEntity:associateParentEntity:queryable:count')
 
 def option_default(args):
-    help = """
-        -default:set key value --> defaults the specified key-value
-        -default:del key    --> deletes the default
-        -default:get key    --> displays the current value
+    help = f"""
+        {utils.CGREEN}-default:set key value{utils.CEND} --> defaults the specified key-value
+        {utils.CGREEN}-default:del key  {utils.CEND}  --> deletes the default
+        {utils.CGREEN}-default:get key  {utils.CEND}  --> displays the current value
         """
 
     if '-h' in args:
@@ -245,75 +251,65 @@ def option_default(args):
         value =restClient.getConfigVar(key)
         print(f"Default value for {key} is {value}")
 
-def option_history(args):
-    if '-h' in args:
+#def option_history(args):
+#    return
+#    if '-h' in args:
         help = """
         -history"""
         return help
-    print()
-    print('HISTORY:')
-    vars = jsonFile.read(varsFile)
-    for line in vars['history']:
+#    print()
+#    print('HISTORY:')
+#    vars = jsonFile.read(varsFile)
+#    for line in vars['history']:
         print(line)
 
 def option_logs(args):
-    help = """
-        -logs:ls --> list last logs
-            -limit how many, default 50 max 200
-            -user "field:value", filter for specified user. The user can be specified by any field in the User Object. Examples:
+    help = f"""
+        {utils.CGREEN}-logs{utils.CEND} --> list logs in the org. 
+            {utils.CGREEN}-limit X{utils.CEND}, where X specifies the number of logs to list. Default 50 max 50K
+            {utils.CGREEN}-loguser field:value{utils.CEND}, filter the logs for the specified user. The user can be specified by any field in the User Object. 
+                Examples:
                     "Id:XXXXXXXX"
                     "name:Onboarding Site Guest User"
+                    "Alias:John.Doe"
                     "FirstName:Onboarding"
                     "ProfileId:00e3O000000IHneQAG"
-        -logs --> parse logs
-            -logs Id --> parse the logs with the provided Id
-            -logs -last:X --> parses the last X logs. 
+                {utils.CPURPLE}Defaultable loguser{utils.CEND}: Can be set to default. -default:set loguser "Alias:John.Doe"
+        {utils.CGREEN}-logs Id{utils.CEND} --> parse the logs with the provided Id
+        {utils.CGREEN}-logs -last X {utils.CEND}--> parses the last X logs. 
         """
 
     if '-h' in args:
         return help
 
-    if '-logs:ls' in args:
-        user = getParam(args,'-user') 
-        last = getParam(args,'-last') 
-        lim = 50 if last == None else last
+    logId = getParam(args,'-logs')    
+    last = getParam(args,'-last')  
+    limit = getParam(args,'-limit')    
+    loguser = getParam(args,'-loguser') 
 
+    if loguser == None:
+        loguser = restClient.getConfigVar('loguser')
+
+    if logId == None and last== None:
         connectionInit(args)
-
+        lim = 50 if limit == None else limit
         id = None
-        if user != None:
-            chunks = user.split(":")
-            key = chunks[0]
-            value = chunks[1]
+        if loguser != None:
+            chunks = loguser.split(":")
+            key = chunks[0] if len(chunks)>1 else 'Id'
+            value = chunks[1] if len(chunks)>1 else chunks[0]
             id = query.queryField(f"Select Id from User where {key}='{value}'") if key.lower()!='id' else value
+            if id == None:
+                utils.raiseException('QUERY',f"User with field {key} = {value} does not exist in the User Object.")
+        if id != None:
+            print(f"Logs for user {loguser}, id:{id}")
         debugLogs.printLogs(logUserId=id,limit=lim)
-    else:
-        logId = getParam(args,'-logs')    
-        last = getParam(args,'-last')    
+        return
 
-        if logId == None and last == None:
-            print(help)
-            return
-
-        connectionInit(args)
-        debugLogs.parseLog(logId,lastN=last)
+    connectionInit(args)
+    debugLogs.parseLog(logId,lastN=last)
 
     return
-    printLimits = False if '-nolimits' in args else True
-    userDebug = False if '-userDebug' in args else True
-    last = True if '-last' in args else False
-    lastN = getParam(args,'-last')  if last == True else 1
-
-    isLogUserId = True if '-userId' in args else False
-    logUserId = getParam(args,'-userId')  if isLogUserId == True else None
-
-    if last == True:
-        logId = None
-        
-    if logId == 'latest':
-        logId = None
-
-    debugLogs.parseLog(logId,printLimits=printLimits,userDebug=userDebug,lastN=lastN,logUserId=logUserId)
 
 def option_h(args):
     module = __import__('InCli')
@@ -332,52 +328,51 @@ def connectionInit(argsIn):
     userName_or_ofgAlias = getParam(argsIn,'-u') 
     restClient.init(userName_or_ofgAlias)
 
-def main(argsIn):
+def _main(argsIn):
+    restClient.setLoggingLevel(logging.INFO)
+
+    if '-h' in argsIn:
+        help = f"""
+    {utils.CGREEN}-u{utils.CEND} --> username or org alias to be used to log into the org. 
+            {utils.CPURPLE}Defaultable u{utils.CEND}: Can be set to a default value --> -default:set u "xx@adas.com"
+    """
+        print(help)
+
+    funcs = getmembers(sys.modules[__name__], isfunction)
+    functions = [func[0] for func in funcs if func[0].startswith('option_')]
+
+    args = []
+    for argv in argsIn:
+        if argv == '|':
+            break
+        args.append(argv)
+
+    for arg in args:
+        ar = arg.split(':')[0][1:]
+        ar = f"option_{ar}"
+        if ar in functions:
+        #       module = __import__('InCli')
+            eval(f'{ar}(args)')
+        #      func = getattr(module, ar)
+        #      func(args)
+
+    if '-h' in argsIn:
+        print()
+        print(utils.CBOLD+"SFDX Commands:"+utils.CEND)
+        print(f" - {utils.CGREEN}sfdx force:org:list --verbose --all {utils.CEND}--> to list all authorized Orgs and Connection Status")
+        print(f" - {utils.CGREEN}sfdx auth:web:login -r 'Instance Url' -a 'Alias' {utils.CEND}--> to re-authorize")
+        print(f" - {utils.CGREEN}sfdx auth:web:login -u 'userName'  -a 'alias' {utils.CEND}--> to authorize and Org")
+        print()
+
+def main():
+    argsIn = sys.argv
     try:
-    #    restClient.setConfigFile('/Users/uormaechea/Documents/Dev/python/Industries/config/ConnectionsParams.json')
-    #    restClient.initWithConfig('DEVNOSCAT2')
-
-        restClient.setLoggingLevel(logging.INFO)
-      #  connectionInit(argsIn)
-
-        # "uormaechea.devnoscat3@nos.pt"
-        if '-h' in argsIn:
-            help = """
-        -u --> username or org alias to be used to log into the org. 
-               Can be set to a default value --> -set u "xx"adas.com"
-        """
-            print(help)
-
-        funcs = getmembers(sys.modules[__name__], isfunction)
-        functions = [func[0] for func in funcs if func[0].startswith('option_')]
-
-        args = []
-        for argv in argsIn:
-            if argv == '|':
-                break
-            args.append(argv)
-
-        for arg in args:
-            ar = arg.split(':')[0][1:]
-            ar = f"option_{ar}"
-            if ar in functions:
-         #       module = __import__('InCli')
-                eval(f'{ar}(args)')
-          #      func = getattr(module, ar)
-          #      func(args)
-
-        if '-h' in argsIn:
-            print()
-            print("SFDX Commands:")
-            print(" - sfdx force:org:list --verbose --all --> to list all authorized Orgs and Connection Status")
-            print(" - sfdx auth:web:login -r 'Instance Url' -a 'Alias' --> to re-authorize")
-            print(" - sfdx auth:web:login -u 'userName'  -a 'alias' --> to authorize and Org")
-            print()
+        _main(argsIn)
 
     except Exception as e:
         utils.printException(e)
         traceback.format_exc()
 
 if __name__ == '__main__':
-    main(sys.argv)
+    main()
 
