@@ -39,7 +39,7 @@ def parseLog(logId=None,printLimits=True,userDebug=True,lastN=1,logUserId=None):
             if logIds == None or len(logIds)==0:
                 utils.raiseException(errorCode='NO_LOG',error=f'No logs can be found. ')
             for logId in logIds:
-                print()
+                print('___________________________________________________________________________________________________________________________________________________________________')
                 print(f"Parsing log Id {logId}")
                 parseLog(logId)
             #    input("Click for next")
@@ -56,7 +56,7 @@ def parseLog(logId=None,printLimits=True,userDebug=True,lastN=1,logUserId=None):
 
 def printLogs(logUserId=None,limit=50):
     logs = queryLogRecords(logUserId,limit=limit)
-    logs = utils.deleteNulls(logs,delSystemFields=False)
+    logs = utils.deleteNulls(logs,systemFields=False)
     utils.printFormated(logs)
 
 def delta(obj,field):
